==> libdatetime-locale-perl_1.16.orig.tar.gz: DateTime-Locale-1.16/share/tzm-MA.pl <==
{
  am_pm_abbreviated => [
    "Zdat azal",
    "\N{U+1e0c}effir aza"
  ],
  available_formats => {
    E => "ccc",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, M/d",
    MMM => "LLL",
    MMMEd => "E, MMM d",
    MMMMEd => "E, MMMM d",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "M/d",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, M/d/y",
    yMMM => "MMM y",
    yMMMEd => "E, MMM d, y",
    yMMMM => "MMMM y",
    yMMMd => "y MMM d",
    yMd => "y-MM-dd",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' y"
  },
  code => "tzm-MA",
  date_format_full => "EEEE, d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "dd/MM/y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "Ayn",
    "Asn",
    "Akr",
    "Akw",
    "Asm",
    "As\N{U+1e0d}",
    "Asa"
  ],
  day_format_narrow => [
    "A",
    "A",
    "A",
    "A",
    "A",
    "A",
    "A"
  ],
  day_format_wide => [
    "Aynas",
    "Asinas",
    "Akras",
    "Akwas",
    "Asimwas",
    "Asi\N{U+1e0d}yas",
    "Asamas"
  ],
  day_stand_alone_abbreviated => [
    "Ayn",
    "Asn",
    "Akr",
    "Akw",
    "Asm",
    "As\N{U+1e0d}",
    "Asa"
  ],
  day_stand_alone_narrow => [
    "A",
    "A",
    "A",
    "A",
    "A",
    "A",
    "A"
  ],
  day_stand_alone_wide => [
    "Aynas",
    "Asinas",
    "Akras",
    "Akwas",
    "Asimwas",
    "Asi\N{U+1e0d}yas",
    "Asamas"
  ],
  era_abbreviated => [
    "Z\N{U+0190}",
    "\N{U+1e0c}\N{U+0190}"
  ],
  era_narrow => [
    "Z\N{U+0190}",
    "\N{U+1e0c}\N{U+0190}"
  ],
  era_wide => [
    "Zdat \N{U+0190}isa (TA\N{U+0194})",
    "\N{U+1e0c}effir \N{U+0190}isa (TA\N{U+0194})"
  ],
  first_day_of_week => 6,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Central Atlas Tamazight",
  month_format_abbreviated => [
    "Yen",
    "Yeb",
    "Mar",
    "Ibr",
    "May",
    "Yun",
    "Yul",
    "\N{U+0194}uc",
    "Cut",
    "K\N{U+1e6d}u",
    "Nwa",
    "Duj"
  ],
  month_format_narrow => [
    "Y",
    "Y",
    "M",
    "I",
    "M",
    "Y",
    "Y",
    "\N{U+0194}",
    "C",
    "K",
    "N",
    "D"
  ],
  month_format_wide => [
    "Yennayer",
    "Yebrayer",
    "Mars",
    "Ibrir",
    "Mayyu",
    "Yunyu",
    "Yulyuz",
    "\N{U+0194}uct",
    "Cutanbir",
    "K\N{U+1e6d}uber",
    "Nwanbir",
    "Dujanbir"
  ],
  month_stand_alone_abbreviated => [
    "Yen",
    "Yeb",
    "Mar",
    "Ibr",
    "May",
    "Yun",
    "Yul",
    "\N{U+0194}uc",
    "Cut",
    "K\N{U+1e6d}u",
    "Nwa",
    "Duj"
  ],
  month_stand_alone_narrow => [
    "Y",
    "Y",
    "M",
    "I",
    "M",
    "Y",
    "Y",
    "\N{U+0194}",
    "C",
    "K",
    "N",
    "D"
  ],
  month_stand_alone_wide => [
    "Yennayer",
    "Yebrayer",
    "Mars",
    "Ibrir",
    "Mayyu",
    "Yunyu",
    "Yulyuz",
    "\N{U+0194}uct",
    "Cutanbir",
    "K\N{U+1e6d}uber",
    "Nwanbir",
    "Dujanbir"
  ],
  name => "Central Atlas Tamazight Morocco",
  native_language => "Tamazi\N{U+0263}t n la\N{U+1e6d}la\N{U+1e63}",
  native_name => "Tamazi\N{U+0263}t n la\N{U+1e6d}la\N{U+1e63} Me\N{U+1e5b}\N{U+1e5b}uk",
  native_script => undef,
  native_territory => "Me\N{U+1e5b}\N{U+1e5b}uk",
  native_variant => undef,
  quarter_format_abbreviated => [
    "IA1",
    "IA2",
    "IA3",
    "IA4"
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4
  ],
  quarter_format_wide => [
    "Imir adamsan 1",
    "Imir adamsan 2",
    "Imir adamsan 3",
    "Imir adamsan 4"
  ],
  quarter_stand_alone_abbreviated => [
    "IA1",
    "IA2",
    "IA3",
    "IA4"
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4
  ],
  quarter_stand_alone_wide => [
    "Imir adamsan 1",
    "Imir adamsan 2",
    "Imir adamsan 3",
    "Imir adamsan 4"
  ],
  script => undef,
  territory => "Morocco",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 31
}

==> libdatetime-locale-perl_1.22.orig.tar.gz: DateTime-Locale-1.22/share/tzm-MA.pl <==
{
  am_pm_abbreviated => [
    "Zdat azal",
    "\N{U+1e0c}effir aza",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, M/d",
    MMM => "LLL",
    MMMEd => "E, MMM d",
    MMMMEd => "E, MMMM d",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "M/d",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, M/d/y",
    yMMM => "MMM y",
    yMMMEd => "E, MMM d, y",
    yMMMM => "MMMM y",
    yMMMd => "y MMM d",
    yMd => "y-MM-dd",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "tzm-MA",
  date_format_full => "EEEE, d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "dd/MM/y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "Ayn",
    "Asn",
    "Akr",
    "Akw",
    "Asm",
    "As\N{U+1e0d}",
    "Asa",
  ],
  day_format_narrow => [
    "A",
    "A",
    "A",
    "A",
    "A",
    "A",
    "A",
  ],
  day_format_wide => [
    "Aynas",
    "Asinas",
    "Akras",
    "Akwas",
    "Asimwas",
    "Asi\N{U+1e0d}yas",
    "Asamas",
  ],
  day_stand_alone_abbreviated => [
    "Ayn",
    "Asn",
    "Akr",
    "Akw",
    "Asm",
    "As\N{U+1e0d}",
    "Asa",
  ],
  day_stand_alone_narrow => [
    "A",
    "A",
    "A",
    "A",
    "A",
    "A",
    "A",
  ],
  day_stand_alone_wide => [
    "Aynas",
    "Asinas",
    "Akras",
    "Akwas",
    "Asimwas",
    "Asi\N{U+1e0d}yas",
    "Asamas",
  ],
  era_abbreviated => [
    "Z\N{U+0190}",
    "\N{U+1e0c}\N{U+0190}",
  ],
  era_narrow => [
    "Z\N{U+0190}",
    "\N{U+1e0c}\N{U+0190}",
  ],
  era_wide => [
    "Zdat \N{U+0190}isa (TA\N{U+0194})",
    "\N{U+1e0c}effir \N{U+0190}isa (TA\N{U+0194})",
  ],
  first_day_of_week => 6,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Central Atlas Tamazight",
  month_format_abbreviated => [
    "Yen",
    "Yeb",
    "Mar",
    "Ibr",
    "May",
    "Yun",
    "Yul",
    "\N{U+0194}uc",
    "Cut",
    "K\N{U+1e6d}u",
    "Nwa",
    "Duj",
  ],
  month_format_narrow => [
    "Y",
    "Y",
    "M",
    "I",
    "M",
    "Y",
    "Y",
    "\N{U+0194}",
    "C",
    "K",
    "N",
    "D",
  ],
  month_format_wide => [
    "Yennayer",
    "Yebrayer",
    "Mars",
    "Ibrir",
    "Mayyu",
    "Yunyu",
    "Yulyuz",
    "\N{U+0194}uct",
    "Cutanbir",
    "K\N{U+1e6d}uber",
    "Nwanbir",
    "Dujanbir",
  ],
  month_stand_alone_abbreviated => [
    "Yen",
    "Yeb",
    "Mar",
    "Ibr",
    "May",
    "Yun",
    "Yul",
    "\N{U+0194}uc",
    "Cut",
    "K\N{U+1e6d}u",
    "Nwa",
    "Duj",
  ],
  month_stand_alone_narrow => [
    "Y",
    "Y",
    "M",
    "I",
    "M",
    "Y",
    "Y",
    "\N{U+0194}",
    "C",
    "K",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "Yennayer",
    "Yebrayer",
    "Mars",
    "Ibrir",
    "Mayyu",
    "Yunyu",
    "Yulyuz",
    "\N{U+0194}uct",
    "Cutanbir",
    "K\N{U+1e6d}uber",
    "Nwanbir",
    "Dujanbir",
  ],
  name => "Central Atlas Tamazight Morocco",
  native_language => "Tamazi\N{U+0263}t n la\N{U+1e6d}la\N{U+1e63}",
  native_name => "Tamazi\N{U+0263}t n la\N{U+1e6d}la\N{U+1e63} Me\N{U+1e5b}\N{U+1e5b}uk",
  native_script => undef,
  native_territory => "Me\N{U+1e5b}\N{U+1e5b}uk",
  native_variant => undef,
  quarter_format_abbreviated => [
    "IA1",
    "IA2",
    "IA3",
    "IA4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "Imir adamsan 1",
    "Imir adamsan 2",
    "Imir adamsan 3",
    "Imir adamsan 4",
  ],
  quarter_stand_alone_abbreviated => [
    "IA1",
    "IA2",
    "IA3",
    "IA4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "Imir adamsan 1",
    "Imir adamsan 2",
    "Imir adamsan 3",
    "Imir adamsan 4",
  ],
  script => undef,
  territory => "Morocco",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 33,
}
